@@ -33,10 +33,14 @@ using namespace UCOMMON_NAMESPACE;
 LinkedObject *service::callback::runlevels[4] = {NULL, NULL, NULL, NULL};
 unsigned service::callback::count = 0;
 unsigned short service::callback::sip_port = 5060;
+unsigned service::callback::sip_prefix = 0;
+unsigned service::callback::sip_range = 0;
 int service::callback::sip_protocol = IPPROTO_UDP;
 int service::callback::sip_family = AF_INET;
 int service::callback::sip_tlsmode = 0;
+const char *service::callback::sip_realm = "unknown";
 const char *service::callback::sip_domain = NULL;
+char service::callback::session_uuid[40];
 condlock_t service::locking;
 service *service::cfg = NULL;
 volatile service::dialmode_t service::dialmode = service::ALL_DIALING;
@@ -160,6 +164,10 @@ void service::callback::reload(service *keys)
 {
 }
 
+void service::callback::publish(service *keys)
+{
+}
+
 void service::callback::start(service *keys)
 {
 }
@@ -881,6 +889,15 @@ void service::commit(const char *user)
 	cfg = this;
 	locking.commit();
 
+	rl = 0;
+	while(rl < RUNLEVELS) {
+		cb = callback::runlevels[rl++];
+		while(is(cb)) {
+			cb->publish(this);
+			cb.next();
+		}
+	}
+
 	// let short-term volatile references settle before we delete it...
 	if(orig) {
 		Thread::sleep(1000);
