@@ -428,8 +428,11 @@ static void usage(void)
 		"  check                   Server deadlock check\n"
         "  concurrency <level>     Server concurrency level\n"
 		"  down                    Shut down server\n"
+		"  drop <user|callid>      Drop an active call\n"
 		"  dump                    Dump server configuration\n"
 		"  history [bufsize]       Set buffer or dump error log\n"
+		"  ifup <iface>            Notify interface came up\n"
+		"  ifdown <iface>          Notify interface went down\n"
 		"  message <ext> <text>    Send text message to extension\n"
 		"  period <interval>       Collect periodic statistics\n"
 		"  pstats                  Dump periodic statistics\n"
@@ -511,6 +514,32 @@ static void state(char **argv)
 	command(argv, 10);
 }
 
+static void iface(char **argv)
+{
+	if(!argv[1]) {
+		fprintf(stderr, "*** sipwitch: %s: interface missing\n", *argv);
+		exit(-1);
+	}
+	if(argv[2]) {
+		fprintf(stderr, "*** sipwitch: %s: too many arguments\n", *argv);
+		exit(-1);
+	}
+	command(argv, 20);
+}
+
+static void drop(char **argv)
+{
+	if(!argv[1]) {
+		fprintf(stderr, "*** sipwitch: drop: user or callid missing\n");
+		exit(-1);
+	}
+	if(argv[2]) {
+		fprintf(stderr, "*** sipwitch: drop: too many arguments\n");
+		exit(-1);
+	}
+	command(argv, 10);
+}
+
 static void release(char **argv)
 {
 	if(!argv[1]) {
@@ -575,44 +604,48 @@ extern "C" int main(int argc, char **argv)
 		usage();
 
 	++argv;
-	if(String::equal(*argv, "version") || String::equal(*argv, "-version") || String::equal(*argv, "--version"))
+	if(eq(*argv, "version") || eq(*argv, "-version") || eq(*argv, "--version"))
 		version();
-	else if(String::equal(*argv, "help") || String::equal(*argv, "-help") || String::equal(*argv, "--help"))
+	else if(eq(*argv, "help") || eq(*argv, "-help") || eq(*argv, "--help"))
 		usage();
-	else if(String::equal(*argv, "reload") || String::equal(*argv, "check") || String::equal(*argv, "snapshot") || String::equal(*argv, "dump") || String::equal(*argv, "siplog"))
+	else if(eq(*argv, "reload") || eq(*argv, "check") || eq(*argv, "snapshot") || eq(*argv, "dump") || eq(*argv, "siplog"))
 		single(argv, 30);
-	else if(String::equal(*argv, "history")) {
+	else if(eq(*argv, "history")) {
 		if(argc == 2)
 			single(argv, 30);
 		else
 			level(argv, 10);
 	}
-	else if(String::equal(*argv, "down") || String::equal(*argv, "restart") || String::equal(*argv, "abort"))
+	else if(eq(*argv, "down") || eq(*argv, "restart") || eq(*argv, "abort"))
 		single(argv, 0);
-	else if(String::equal(*argv, "verbose") || String::equal(*argv, "concurrency") || String::equal(*argv, "trace"))
+	else if(eq(*argv, "verbose") || eq(*argv, "concurrency") || eq(*argv, "trace"))
 		level(argv, 10);
-	else if(String::equal(*argv, "message"))
+	else if(eq(*argv, "message"))
 		message(argv);
-	else if(String::equal(*argv, "registry"))
+	else if(eq(*argv, "registry"))
 		registry(argv);
-	else if(String::equal(*argv, "stats"))
+	else if(eq(*argv, "stats"))
 		dumpstats(argv);
-	else if(String::equal(*argv, "calls"))
+	else if(eq(*argv, "calls"))
 		calls(argv);
-	else if(String::equal(*argv, "pstats"))
+	else if(eq(*argv, "pstats"))
 		periodic(argv);
-	else if(String::equal(*argv, "address"))
+	else if(eq(*argv, "address"))
 		address(argv);
-	else if(String::equal(*argv, "period"))
+	else if(eq(*argv, "period"))
 		period(argv);
-	else if(String::equal(*argv, "activate"))
+	else if(eq(*argv, "activate"))
 		activate(argv);
-	else if(String::equal(*argv, "release"))
+	else if(eq(*argv, "release"))
 		release(argv);
-	else if(String::equal(*argv, "state"))
+	else if(eq(*argv, "state"))
 		state(argv);
-	else if(String::equal(*argv, "status"))
+	else if(eq(*argv, "status"))
 		status(argv);
+	else if(eq(*argv, "ifdown") || eq(*argv, "ifup"))
+		iface(argv);
+	else if(eq(*argv, "drop"))
+		drop(argv);
 	if(!argv[1])
 		fprintf(stderr, "use: sipwitch command [arguments...]\n");
 	else
